@@ -1,4 +1,5 @@
 from .facebook_bot import (get_page_ids,
                            get_events,
                            get_events_by_location,
-                           get_page_info)
+                           get_page_info,
+                           get_event_info)
